@@ -256,17 +256,17 @@ def download_zentao_file(filename):
 
     return send_from_directory(app.config['UPLOAD_FOLDER'], filename, as_attachment=True)
 
-# @app.route('/<filename>/to/zentao')
-# def download_zentao_xlsx_file(filename):
-#     full_path = join(app.config['UPLOAD_FOLDER'], filename)
-#
-#     if not exists(full_path):
-#         abort(404)
-#
-#     zentao_xlsx_file = xmind_to_testrail_xlsx_file(full_path)
-#     filename = os.path.basename(zentao_xlsx_file) if zentao_xlsx_file else abort(404)
-#
-#     return send_from_directory(app.config['UPLOAD_FOLDER'], filename, as_attachment=True)
+@app.route('/<filename>/to/zentao_xlsx')
+def download_zentao_xlsx_file(filename):
+    full_path = join(app.config['UPLOAD_FOLDER'], filename)
+
+    if not exists(full_path):
+        abort(404)
+
+    zentao_xlsx_file = xmind_to_testrail_xlsx_file(full_path)
+    filename = os.path.basename(zentao_xlsx_file) if zentao_xlsx_file else abort(404)
+
+    return send_from_directory(app.config['UPLOAD_FOLDER'], filename, as_attachment=True)
 
 
 @app.route('/preview/<filename>')
