@@ -13,52 +13,30 @@ Convert XMind fie to TestRail testcase csv file
 
 
 def xmind_to_testrail_csv_file(xmind_file):
-    """Convert XMind file to a testrail xlsx file"""
+    """Convert XMind file to a testrail csv file"""
     xmind_file = get_absolute_path(xmind_file)   # 获取xmind的绝对路径
     logging.info('Start converting XMind file(%s) to testrail file...', xmind_file)   # 打印日志信息
     testcases = get_xmind_testcase_list(xmind_file)   # 获取testcase
     # print(testcases)
+    # fileheader = ["Section", "Title", "优先级", "版本", "前置条件", "测试步骤", "预期结果"]   # csv表格标题
     fileheader = ["用例名称", "所属产品", "所属模块", "用例等级", "用例类型", "前提条件", "用例步骤", "预期结果"]   # csv表格标题
     testrail_testcase_rows = [fileheader]
     for testcase in testcases:
         row = gen_a_testcase_row(testcase)
         testrail_testcase_rows.append(row)
 
-    testrail_file = xmind_file[:-6] + '.xlsx'
+    testrail_file = xmind_file[:-6] + '.csv'
     if os.path.exists(testrail_file):
         os.remove(testrail_file)
         # logging.info('The testrail csv file already exists, return it directly: %s', testrail_file)
         # return testrail_file
-        df = pd.DataFrame(data=testrail_testcase_rows, columns=fileheader)  # 构造数据
-        df.to_excel(testrail_file, index=False)  # 写入文件，设置不需要索引
-        logging.info('Convert XMind file(%s) to a testrail xlsx file(%s) successfully!', xmind_file, testrail_file)
+
+    with open(testrail_file, 'w', encoding='utf8', newline='') as f:
+        writer = csv.writer(f)
+        writer.writerows(testrail_testcase_rows)
+        logging.info('Convert XMind file(%s) to a testrail csv file(%s) successfully!', xmind_file, testrail_file)
 
     return testrail_file
-# def xmind_to_testrail_csv_file(xmind_file):
-#     """Convert XMind file to a testrail csv file"""
-#     xmind_file = get_absolute_path(xmind_file)   # 获取xmind的绝对路径
-#     logging.info('Start converting XMind file(%s) to testrail file...', xmind_file)   # 打印日志信息
-#     testcases = get_xmind_testcase_list(xmind_file)   # 获取testcase
-#     # print(testcases)
-#     # fileheader = ["Section", "Title", "优先级", "版本", "前置条件", "测试步骤", "预期结果"]   # csv表格标题
-#     fileheader = ["用例名称", "所属模块", "用例等级", "前提条件", "用例步骤", "预期结果"]   # csv表格标题
-#     testrail_testcase_rows = [fileheader]
-#     for testcase in testcases:
-#         row = gen_a_testcase_row(testcase)
-#         testrail_testcase_rows.append(row)
-#
-#     testrail_file = xmind_file[:-6] + '.csv'
-#     if os.path.exists(testrail_file):
-#         os.remove(testrail_file)
-#         # logging.info('The testrail csv file already exists, return it directly: %s', testrail_file)
-#         # return testrail_file
-#
-#     with open(testrail_file, 'w', encoding='utf8', newline='') as f:
-#         writer = csv.writer(f)
-#         writer.writerows(testrail_testcase_rows)
-#         logging.info('Convert XMind file(%s) to a testrail csv file(%s) successfully!', xmind_file, testrail_file)
-#
-#     return testrail_file
 def xmind_to_testrail_xlsx_file(xmind_file):
     """Convert XMind file to a testrail xlsx file"""
     xmind_file = get_absolute_path(xmind_file)   # 获取xmind的绝对路径
@@ -157,10 +135,10 @@ def gen_case_type(case_type):
     else:
         return '功能'
 
-
-if __name__ == '__main__':
-    # xmind_file = '../docs/testrail_testcase_template.xmind'
-    xmind_file = 'C:/Users/YYS/Desktop/草帽云V1.5.0测试用例.xmind'
-    # get_xmind_testcase_list(xmind_file)
-    testrail_csv_file = xmind_to_testrail_xlsx_file(xmind_file)
+#
+# if __name__ == '__main__':
+#     # xmind_file = '../docs/testrail_testcase_template.xmind'
+#     xmind_file = 'C:/Users/YYS/Desktop/草帽云V1.5.0测试用例.xmind'
+#     # get_xmind_testcase_list(xmind_file)
+#     testrail_csv_file = xmind_to_testrail_xlsx_file(xmind_file)
     # print('Conver the xmind file to a testrail csv file succssfully: %s', testrail_csv_file)
\ No newline at end of file
